GraphQL

ASGI GraphQL app with root value(s).

Usage

GraphQL(
    root,
    extensions=(),
    **kwargs,
)

Parameters

Name Type Description Default
root root dataset, Query type, or instance to attach as the Query root -
extensions additional extensions to enable **kwargs: additional asgi.GraphQL options -

Attributes

Name Description
options dict() -> new empty dictionary

options

dict() -> new empty dictionary

options=dict(
    types=(Column.registry.values()),
    config=(strawberry.schema.config.StrawberryConfig(scalar_map=scalar_map)),
)

dict(mapping) -> new dictionary initialized from a mapping object’s (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable: d[k] = v dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list. For example: dict(one=1, two=2)

Methods

Name Description
federated() Deprecated: construct GraphQL app with multiple federated datasets.

federated()

Deprecated: construct GraphQL app with multiple federated datasets.

Usage

federated(roots, keys={}, **kwargs)

Create a Query class with typed fields using typed instead. See customize docs.