implement()
Create Table type which implements Dataset interface with schema-aware fields.
Usage
implement(
schema,
name="",
keys=(),
)Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| schema | ibis schema | - | |
| name | optional name of the dataset, prefixed to the type names | - | |
| keys | keys for federation | - |