GraphQL

ASGI GraphQL app with root value(s).

Usage

GraphQL()

Parameters

root

root dataset to attach as the Query type metrics: enable timing extension **kwargs: additional asgi.GraphQL options

Attributes

Name Description
options dict() -> new empty dictionary

options

dict() -> new empty dictionary

options=dict(
    types=(Column.registry.values()),
    config=(strawberry.schema.config.StrawberryConfig(scalar_map=scalar_map)),
)

dict(mapping) -> new dictionary initialized from a mapping object’s (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable: d[k] = v dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list. For example: dict(one=1, two=2)

Methods

Name Description
federated() Construct GraphQL app with multiple federated datasets.

federated()

Construct GraphQL app with multiple federated datasets.

Usage

federated(roots, keys={}, **kwargs)

Parameters

roots

mapping of field names to root datasets keys: mapping of optional federation keys for each root **kwargs: additional asgi.GraphQL options